<?php

namespace Drupal\wp_publish\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configuration form for WordPress Publish settings.
 */
class WpPublishSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'wp_publish_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['wp_publish.settings'];
  }

  /**
   * Builds the form for configuring WordPress connection settings.
   *
   * @param array $form
   *   The form structure.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The form state.
   *
   * @return array
   *   The form structure.
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('wp_publish.settings');

    $form['wordpress_url'] = [
      '#type' => 'url',
      '#title' => $this->t('WordPress Site URL'),
      '#default_value' => $config->get('wordpress_url'),
      '#required' => TRUE,
    ];

    $form['wordpress_username'] = [
      '#type' => 'textfield',
      '#title' => $this->t('WordPress Username'),
      '#default_value' => $config->get('wordpress_username'),
      '#required' => TRUE,
    ];

    $form['wordpress_app_password'] = [
      '#type' => 'password',
      '#title' => $this->t('WordPress Application Password'),
      '#default_value' => $config->get('wordpress_app_password'),
      '#required' => TRUE,
    ];

    $form['enabled_content_types'] = [
      '#type' => 'checkboxes',
      '#title' => $this->t('Enable for Content Types'),
      '#options' => array_combine(
        array_keys(node_type_get_names()),
        node_type_get_names()
      ),
      '#default_value' => $config->get('enabled_content_types') ?? [],
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * Saves the WordPress connection settings.
   *
   * @param array $form
   *   The form structure.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The form state.
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('wp_publish.settings')
      ->set('wordpress_url', $form_state->getValue('wordpress_url'))
      ->set('wordpress_username', $form_state->getValue('wordpress_username'))
      ->set('wordpress_app_password', $form_state->getValue('wordpress_app_password'))
      ->set('enabled_content_types', array_filter($form_state->getValue('enabled_content_types')))
      ->save();

    parent::submitForm($form, $form_state);
  }
}
